Class: Aws::AppSync::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::AppSync::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-appsync/client.rb,
sig/client.rbs
Overview
An API client for AppSync. To construct a client, you need to configure a :region and :credentials.
client = Aws::AppSync::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateApiResponseSuccess, _AssociateMergedGraphqlApiResponseSuccess, _AssociateSourceGraphqlApiResponseSuccess, _CreateApiCacheResponseSuccess, _CreateApiKeyResponseSuccess, _CreateApiResponseSuccess, _CreateChannelNamespaceResponseSuccess, _CreateDataSourceResponseSuccess, _CreateDomainNameResponseSuccess, _CreateFunctionResponseSuccess, _CreateGraphqlApiResponseSuccess, _CreateResolverResponseSuccess, _CreateTypeResponseSuccess, _DeleteApiCacheResponseSuccess, _DeleteApiKeyResponseSuccess, _DeleteApiResponseSuccess, _DeleteChannelNamespaceResponseSuccess, _DeleteDataSourceResponseSuccess, _DeleteDomainNameResponseSuccess, _DeleteFunctionResponseSuccess, _DeleteGraphqlApiResponseSuccess, _DeleteResolverResponseSuccess, _DeleteTypeResponseSuccess, _DisassociateApiResponseSuccess, _DisassociateMergedGraphqlApiResponseSuccess, _DisassociateSourceGraphqlApiResponseSuccess, _EvaluateCodeResponseSuccess, _EvaluateMappingTemplateResponseSuccess, _FlushApiCacheResponseSuccess, _GetApiAssociationResponseSuccess, _GetApiCacheResponseSuccess, _GetApiResponseSuccess, _GetChannelNamespaceResponseSuccess, _GetDataSourceIntrospectionResponseSuccess, _GetDataSourceResponseSuccess, _GetDomainNameResponseSuccess, _GetFunctionResponseSuccess, _GetGraphqlApiEnvironmentVariablesResponseSuccess, _GetGraphqlApiResponseSuccess, _GetIntrospectionSchemaResponseSuccess, _GetResolverResponseSuccess, _GetSchemaCreationStatusResponseSuccess, _GetSourceApiAssociationResponseSuccess, _GetTypeResponseSuccess, _ListApiKeysResponseSuccess, _ListApisResponseSuccess, _ListChannelNamespacesResponseSuccess, _ListDataSourcesResponseSuccess, _ListDomainNamesResponseSuccess, _ListFunctionsResponseSuccess, _ListGraphqlApisResponseSuccess, _ListResolversByFunctionResponseSuccess, _ListResolversResponseSuccess, _ListSourceApiAssociationsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTypesByAssociationResponseSuccess, _ListTypesResponseSuccess, _PutGraphqlApiEnvironmentVariablesResponseSuccess, _StartDataSourceIntrospectionResponseSuccess, _StartSchemaCreationResponseSuccess, _StartSchemaMergeResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateApiCacheResponseSuccess, _UpdateApiKeyResponseSuccess, _UpdateApiResponseSuccess, _UpdateChannelNamespaceResponseSuccess, _UpdateDataSourceResponseSuccess, _UpdateDomainNameResponseSuccess, _UpdateFunctionResponseSuccess, _UpdateGraphqlApiResponseSuccess, _UpdateResolverResponseSuccess, _UpdateSourceApiAssociationResponseSuccess, _UpdateTypeResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_api(params = {}) ⇒ Types::AssociateApiResponse
Maps an endpoint to your custom domain.
-
#associate_merged_graphql_api(params = {}) ⇒ Types::AssociateMergedGraphqlApiResponse
Creates an association between a Merged API and source API using the source API's identifier.
-
#associate_source_graphql_api(params = {}) ⇒ Types::AssociateSourceGraphqlApiResponse
Creates an association between a Merged API and source API using the Merged API's identifier.
-
#create_api(params = {}) ⇒ Types::CreateApiResponse
Creates an
Apiobject. -
#create_api_cache(params = {}) ⇒ Types::CreateApiCacheResponse
Creates a cache for the GraphQL API.
-
#create_api_key(params = {}) ⇒ Types::CreateApiKeyResponse
Creates a unique key that you can distribute to clients who invoke your API.
-
#create_channel_namespace(params = {}) ⇒ Types::CreateChannelNamespaceResponse
Creates a
ChannelNamespacefor anApi. -
#create_data_source(params = {}) ⇒ Types::CreateDataSourceResponse
Creates a
DataSourceobject. -
#create_domain_name(params = {}) ⇒ Types::CreateDomainNameResponse
Creates a custom
DomainNameobject. -
#create_function(params = {}) ⇒ Types::CreateFunctionResponse
Creates a
Functionobject. -
#create_graphql_api(params = {}) ⇒ Types::CreateGraphqlApiResponse
Creates a
GraphqlApiobject. -
#create_resolver(params = {}) ⇒ Types::CreateResolverResponse
Creates a
Resolverobject. -
#create_type(params = {}) ⇒ Types::CreateTypeResponse
Creates a
Typeobject. -
#delete_api(params = {}) ⇒ Struct
Deletes an
Apiobject. -
#delete_api_cache(params = {}) ⇒ Struct
Deletes an
ApiCacheobject. -
#delete_api_key(params = {}) ⇒ Struct
Deletes an API key.
-
#delete_channel_namespace(params = {}) ⇒ Struct
Deletes a
ChannelNamespace. -
#delete_data_source(params = {}) ⇒ Struct
Deletes a
DataSourceobject. -
#delete_domain_name(params = {}) ⇒ Struct
Deletes a custom
DomainNameobject. -
#delete_function(params = {}) ⇒ Struct
Deletes a
Function. -
#delete_graphql_api(params = {}) ⇒ Struct
Deletes a
GraphqlApiobject. -
#delete_resolver(params = {}) ⇒ Struct
Deletes a
Resolverobject. -
#delete_type(params = {}) ⇒ Struct
Deletes a
Typeobject. -
#disassociate_api(params = {}) ⇒ Struct
Removes an
ApiAssociationobject from a custom domain. -
#disassociate_merged_graphql_api(params = {}) ⇒ Types::DisassociateMergedGraphqlApiResponse
Deletes an association between a Merged API and source API using the source API's identifier and the association ID.
-
#disassociate_source_graphql_api(params = {}) ⇒ Types::DisassociateSourceGraphqlApiResponse
Deletes an association between a Merged API and source API using the Merged API's identifier and the association ID.
-
#evaluate_code(params = {}) ⇒ Types::EvaluateCodeResponse
Evaluates the given code and returns the response.
-
#evaluate_mapping_template(params = {}) ⇒ Types::EvaluateMappingTemplateResponse
Evaluates a given template and returns the response.
-
#flush_api_cache(params = {}) ⇒ Struct
Flushes an
ApiCacheobject. -
#get_api(params = {}) ⇒ Types::GetApiResponse
Retrieves an
Apiobject. -
#get_api_association(params = {}) ⇒ Types::GetApiAssociationResponse
Retrieves an
ApiAssociationobject. -
#get_api_cache(params = {}) ⇒ Types::GetApiCacheResponse
Retrieves an
ApiCacheobject. -
#get_channel_namespace(params = {}) ⇒ Types::GetChannelNamespaceResponse
Retrieves the channel namespace for a specified
Api. -
#get_data_source(params = {}) ⇒ Types::GetDataSourceResponse
Retrieves a
DataSourceobject. -
#get_data_source_introspection(params = {}) ⇒ Types::GetDataSourceIntrospectionResponse
Retrieves the record of an existing introspection.
-
#get_domain_name(params = {}) ⇒ Types::GetDomainNameResponse
Retrieves a custom
DomainNameobject. -
#get_function(params = {}) ⇒ Types::GetFunctionResponse
Get a
Function. -
#get_graphql_api(params = {}) ⇒ Types::GetGraphqlApiResponse
Retrieves a
GraphqlApiobject. -
#get_graphql_api_environment_variables(params = {}) ⇒ Types::GetGraphqlApiEnvironmentVariablesResponse
Retrieves the list of environmental variable key-value pairs associated with an API by its ID value.
-
#get_introspection_schema(params = {}) ⇒ Types::GetIntrospectionSchemaResponse
Retrieves the introspection schema for a GraphQL API.
-
#get_resolver(params = {}) ⇒ Types::GetResolverResponse
Retrieves a
Resolverobject. -
#get_schema_creation_status(params = {}) ⇒ Types::GetSchemaCreationStatusResponse
Retrieves the current status of a schema creation operation.
-
#get_source_api_association(params = {}) ⇒ Types::GetSourceApiAssociationResponse
Retrieves a
SourceApiAssociationobject. -
#get_type(params = {}) ⇒ Types::GetTypeResponse
Retrieves a
Typeobject. -
#list_api_keys(params = {}) ⇒ Types::ListApiKeysResponse
Lists the API keys for a given API.
-
#list_apis(params = {}) ⇒ Types::ListApisResponse
Lists the APIs in your AppSync account.
-
#list_channel_namespaces(params = {}) ⇒ Types::ListChannelNamespacesResponse
Lists the channel namespaces for a specified
Api. -
#list_data_sources(params = {}) ⇒ Types::ListDataSourcesResponse
Lists the data sources for a given API.
-
#list_domain_names(params = {}) ⇒ Types::ListDomainNamesResponse
Lists multiple custom domain names.
-
#list_functions(params = {}) ⇒ Types::ListFunctionsResponse
List multiple functions.
-
#list_graphql_apis(params = {}) ⇒ Types::ListGraphqlApisResponse
Lists your GraphQL APIs.
-
#list_resolvers(params = {}) ⇒ Types::ListResolversResponse
Lists the resolvers for a given API and type.
-
#list_resolvers_by_function(params = {}) ⇒ Types::ListResolversByFunctionResponse
List the resolvers that are associated with a specific function.
-
#list_source_api_associations(params = {}) ⇒ Types::ListSourceApiAssociationsResponse
Lists the
SourceApiAssociationSummarydata. -
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for a resource.
-
#list_types(params = {}) ⇒ Types::ListTypesResponse
Lists the types for a given API.
-
#list_types_by_association(params = {}) ⇒ Types::ListTypesByAssociationResponse
Lists
Typeobjects by the source API association ID. -
#put_graphql_api_environment_variables(params = {}) ⇒ Types::PutGraphqlApiEnvironmentVariablesResponse
Creates a list of environmental variables in an API by its ID value.
-
#start_data_source_introspection(params = {}) ⇒ Types::StartDataSourceIntrospectionResponse
Creates a new introspection.
-
#start_schema_creation(params = {}) ⇒ Types::StartSchemaCreationResponse
Adds a new schema to your GraphQL API.
-
#start_schema_merge(params = {}) ⇒ Types::StartSchemaMergeResponse
Initiates a merge operation.
-
#tag_resource(params = {}) ⇒ Struct
Tags a resource with user-supplied tags.
-
#untag_resource(params = {}) ⇒ Struct
Untags a resource.
-
#update_api(params = {}) ⇒ Types::UpdateApiResponse
Updates an
Api. -
#update_api_cache(params = {}) ⇒ Types::UpdateApiCacheResponse
Updates the cache for the GraphQL API.
-
#update_api_key(params = {}) ⇒ Types::UpdateApiKeyResponse
Updates an API key.
-
#update_channel_namespace(params = {}) ⇒ Types::UpdateChannelNamespaceResponse
Updates a
ChannelNamespaceassociated with anApi. -
#update_data_source(params = {}) ⇒ Types::UpdateDataSourceResponse
Updates a
DataSourceobject. -
#update_domain_name(params = {}) ⇒ Types::UpdateDomainNameResponse
Updates a custom
DomainNameobject. -
#update_function(params = {}) ⇒ Types::UpdateFunctionResponse
Updates a
Functionobject. -
#update_graphql_api(params = {}) ⇒ Types::UpdateGraphqlApiResponse
Updates a
GraphqlApiobject. -
#update_resolver(params = {}) ⇒ Types::UpdateResolverResponse
Updates a
Resolverobject. -
#update_source_api_association(params = {}) ⇒ Types::UpdateSourceApiAssociationResponse
Updates some of the configuration choices of a particular source API association.
-
#update_type(params = {}) ⇒ Types::UpdateTypeResponse
Updates a
Typeobject.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-appsync/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5129 5130 5131 |
# File 'lib/aws-sdk-appsync/client.rb', line 5129 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5132 5133 5134 |
# File 'lib/aws-sdk-appsync/client.rb', line 5132 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_api(params = {}) ⇒ Types::AssociateApiResponse
Maps an endpoint to your custom domain.
86 |
# File 'sig/client.rbs', line 86
def associate_api: (
|
#associate_merged_graphql_api(params = {}) ⇒ Types::AssociateMergedGraphqlApiResponse
Creates an association between a Merged API and source API using the source API's identifier.
97 |
# File 'sig/client.rbs', line 97
def associate_merged_graphql_api: (
|
#associate_source_graphql_api(params = {}) ⇒ Types::AssociateSourceGraphqlApiResponse
Creates an association between a Merged API and source API using the Merged API's identifier.
112 |
# File 'sig/client.rbs', line 112
def associate_source_graphql_api: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5102 5103 5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 |
# File 'lib/aws-sdk-appsync/client.rb', line 5102 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::AppSync') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-appsync' context[:gem_version] = '1.127.0' Seahorse::Client::Request.new(handlers, context) end |
#create_api(params = {}) ⇒ Types::CreateApiResponse
Creates an Api object. Use this operation to create an AppSync API
with your preferred configuration, such as an Event API that provides
real-time message publishing and message subscriptions over
WebSockets.
127 |
# File 'sig/client.rbs', line 127
def create_api: (
|
#create_api_cache(params = {}) ⇒ Types::CreateApiCacheResponse
Creates a cache for the GraphQL API.
140 |
# File 'sig/client.rbs', line 140
def create_api_cache: (
|
#create_api_key(params = {}) ⇒ Types::CreateApiKeyResponse
Creates a unique key that you can distribute to clients who invoke your API.
156 |
# File 'sig/client.rbs', line 156
def create_api_key: (
|
#create_channel_namespace(params = {}) ⇒ Types::CreateChannelNamespaceResponse
Creates a ChannelNamespace for an Api.
168 |
# File 'sig/client.rbs', line 168
def create_channel_namespace: (
|
#create_data_source(params = {}) ⇒ Types::CreateDataSourceResponse
Creates a DataSource object.
192 |
# File 'sig/client.rbs', line 192
def create_data_source: (
|
#create_domain_name(params = {}) ⇒ Types::CreateDomainNameResponse
Creates a custom DomainName object.
224 |
# File 'sig/client.rbs', line 224
def create_domain_name: (
|
#create_function(params = {}) ⇒ Types::CreateFunctionResponse
Creates a Function object.
A function is a reusable entity. You can use multiple functions to compose the resolver logic.
237 |
# File 'sig/client.rbs', line 237
def create_function: (
|
#create_graphql_api(params = {}) ⇒ Types::CreateGraphqlApiResponse
Creates a GraphqlApi object.
266 |
# File 'sig/client.rbs', line 266
def create_graphql_api: (
|
#create_resolver(params = {}) ⇒ Types::CreateResolverResponse
Creates a Resolver object.
A resolver converts incoming requests into a format that a data source can understand, and converts the data source's responses into GraphQL.
316 |
# File 'sig/client.rbs', line 316
def create_resolver: (
|
#create_type(params = {}) ⇒ Types::CreateTypeResponse
Creates a Type object.
353 |
# File 'sig/client.rbs', line 353
def create_type: (
|
#delete_api(params = {}) ⇒ Struct
Deletes an Api object
364 |
# File 'sig/client.rbs', line 364
def delete_api: (
|
#delete_api_cache(params = {}) ⇒ Struct
Deletes an ApiCache object.
373 |
# File 'sig/client.rbs', line 373
def delete_api_cache: (
|
#delete_api_key(params = {}) ⇒ Struct
Deletes an API key.
382 |
# File 'sig/client.rbs', line 382
def delete_api_key: (
|
#delete_channel_namespace(params = {}) ⇒ Struct
Deletes a ChannelNamespace.
392 |
# File 'sig/client.rbs', line 392
def delete_channel_namespace: (
|
#delete_data_source(params = {}) ⇒ Struct
Deletes a DataSource object.
402 |
# File 'sig/client.rbs', line 402
def delete_data_source: (
|
#delete_domain_name(params = {}) ⇒ Struct
Deletes a custom DomainName object.
412 |
# File 'sig/client.rbs', line 412
def delete_domain_name: (
|
#delete_function(params = {}) ⇒ Struct
Deletes a Function.
421 |
# File 'sig/client.rbs', line 421
def delete_function: (
|
#delete_graphql_api(params = {}) ⇒ Struct
Deletes a GraphqlApi object.
431 |
# File 'sig/client.rbs', line 431
def delete_graphql_api: (
|
#delete_resolver(params = {}) ⇒ Struct
Deletes a Resolver object.
440 |
# File 'sig/client.rbs', line 440
def delete_resolver: (
|
#delete_type(params = {}) ⇒ Struct
Deletes a Type object.
451 |
# File 'sig/client.rbs', line 451
def delete_type: (
|
#disassociate_api(params = {}) ⇒ Struct
Removes an ApiAssociation object from a custom domain.
461 |
# File 'sig/client.rbs', line 461
def disassociate_api: (
|
#disassociate_merged_graphql_api(params = {}) ⇒ Types::DisassociateMergedGraphqlApiResponse
Deletes an association between a Merged API and source API using the source API's identifier and the association ID.
471 |
# File 'sig/client.rbs', line 471
def disassociate_merged_graphql_api: (
|
#disassociate_source_graphql_api(params = {}) ⇒ Types::DisassociateSourceGraphqlApiResponse
Deletes an association between a Merged API and source API using the Merged API's identifier and the association ID.
482 |
# File 'sig/client.rbs', line 482
def disassociate_source_graphql_api: (
|
#evaluate_code(params = {}) ⇒ Types::EvaluateCodeResponse
Evaluates the given code and returns the response. The code definition
requirements depend on the specified runtime. For APPSYNC_JS
runtimes, the code defines the request and response functions. The
request function takes the incoming request after a GraphQL operation
is parsed and converts it into a request configuration for the
selected data source operation. The response function interprets
responses from the data source and maps it to the shape of the GraphQL
field output type.
496 |
# File 'sig/client.rbs', line 496
def evaluate_code: (
|
#evaluate_mapping_template(params = {}) ⇒ Types::EvaluateMappingTemplateResponse
Evaluates a given template and returns the response. The mapping template can be a request or response template.
Request templates take the incoming request after a GraphQL operation is parsed and convert it into a request configuration for the selected data source operation. Response templates interpret responses from the data source and map it to the shape of the GraphQL field output type.
Mapping templates are written in the Apache Velocity Template Language (VTL).
515 |
# File 'sig/client.rbs', line 515
def evaluate_mapping_template: (
|
#flush_api_cache(params = {}) ⇒ Struct
Flushes an ApiCache object.
525 |
# File 'sig/client.rbs', line 525
def flush_api_cache: (
|
#get_api(params = {}) ⇒ Types::GetApiResponse
Retrieves an Api object.
535 |
# File 'sig/client.rbs', line 535
def get_api: (
|
#get_api_association(params = {}) ⇒ Types::GetApiAssociationResponse
Retrieves an ApiAssociation object.
545 |
# File 'sig/client.rbs', line 545
def get_api_association: (
|
#get_api_cache(params = {}) ⇒ Types::GetApiCacheResponse
Retrieves an ApiCache object.
555 |
# File 'sig/client.rbs', line 555
def get_api_cache: (
|
#get_channel_namespace(params = {}) ⇒ Types::GetChannelNamespaceResponse
Retrieves the channel namespace for a specified Api.
565 |
# File 'sig/client.rbs', line 565
def get_channel_namespace: (
|
#get_data_source(params = {}) ⇒ Types::GetDataSourceResponse
Retrieves a DataSource object.
576 |
# File 'sig/client.rbs', line 576
def get_data_source: (
|
#get_data_source_introspection(params = {}) ⇒ Types::GetDataSourceIntrospectionResponse
Retrieves the record of an existing introspection. If the retrieval is successful, the result of the instrospection will also be returned. If the retrieval fails the operation, an error message will be returned instead.
590 |
# File 'sig/client.rbs', line 590
def get_data_source_introspection: (
|
#get_domain_name(params = {}) ⇒ Types::GetDomainNameResponse
Retrieves a custom DomainName object.
603 |
# File 'sig/client.rbs', line 603
def get_domain_name: (
|
#get_function(params = {}) ⇒ Types::GetFunctionResponse
Get a Function.
613 |
# File 'sig/client.rbs', line 613
def get_function: (
|
#get_graphql_api(params = {}) ⇒ Types::GetGraphqlApiResponse
Retrieves a GraphqlApi object.
624 |
# File 'sig/client.rbs', line 624
def get_graphql_api: (
|
#get_graphql_api_environment_variables(params = {}) ⇒ Types::GetGraphqlApiEnvironmentVariablesResponse
Retrieves the list of environmental variable key-value pairs associated with an API by its ID value.
634 |
# File 'sig/client.rbs', line 634
def get_graphql_api_environment_variables: (
|
#get_introspection_schema(params = {}) ⇒ Types::GetIntrospectionSchemaResponse
Retrieves the introspection schema for a GraphQL API.
644 |
# File 'sig/client.rbs', line 644
def get_introspection_schema: (
|
#get_resolver(params = {}) ⇒ Types::GetResolverResponse
Retrieves a Resolver object.
656 |
# File 'sig/client.rbs', line 656
def get_resolver: (
|
#get_schema_creation_status(params = {}) ⇒ Types::GetSchemaCreationStatusResponse
Retrieves the current status of a schema creation operation.
669 |
# File 'sig/client.rbs', line 669
def get_schema_creation_status: (
|
#get_source_api_association(params = {}) ⇒ Types::GetSourceApiAssociationResponse
Retrieves a SourceApiAssociation object.
679 |
# File 'sig/client.rbs', line 679
def get_source_api_association: (
|
#get_type(params = {}) ⇒ Types::GetTypeResponse
Retrieves a Type object.
690 |
# File 'sig/client.rbs', line 690
def get_type: (
|
#list_api_keys(params = {}) ⇒ Types::ListApiKeysResponse
Lists the API keys for a given API.
DeleteApiKey to manually delete a
key before it's automatically deleted.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
703 |
# File 'sig/client.rbs', line 703
def list_api_keys: (
|
#list_apis(params = {}) ⇒ Types::ListApisResponse
Lists the APIs in your AppSync account.
ListApis returns only the high level API details. For more detailed
information about an API, use GetApi.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
716 |
# File 'sig/client.rbs', line 716
def list_apis: (
|
#list_channel_namespaces(params = {}) ⇒ Types::ListChannelNamespacesResponse
Lists the channel namespaces for a specified Api.
ListChannelNamespaces returns only high level details for the
channel namespace. To retrieve code handlers, use
GetChannelNamespace.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
728 |
# File 'sig/client.rbs', line 728
def list_channel_namespaces: (
|
#list_data_sources(params = {}) ⇒ Types::ListDataSourcesResponse
Lists the data sources for a given API.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
741 |
# File 'sig/client.rbs', line 741
def list_data_sources: (
|
#list_domain_names(params = {}) ⇒ Types::ListDomainNamesResponse
Lists multiple custom domain names.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
754 |
# File 'sig/client.rbs', line 754
def list_domain_names: (
|
#list_functions(params = {}) ⇒ Types::ListFunctionsResponse
List multiple functions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
766 |
# File 'sig/client.rbs', line 766
def list_functions: (
|
#list_graphql_apis(params = {}) ⇒ Types::ListGraphqlApisResponse
Lists your GraphQL APIs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
779 |
# File 'sig/client.rbs', line 779
def list_graphql_apis: (
|
#list_resolvers(params = {}) ⇒ Types::ListResolversResponse
Lists the resolvers for a given API and type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
793 |
# File 'sig/client.rbs', line 793
def list_resolvers: (
|
#list_resolvers_by_function(params = {}) ⇒ Types::ListResolversByFunctionResponse
List the resolvers that are associated with a specific function.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
807 |
# File 'sig/client.rbs', line 807
def list_resolvers_by_function: (
|
#list_source_api_associations(params = {}) ⇒ Types::ListSourceApiAssociationsResponse
Lists the SourceApiAssociationSummary data.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
821 |
# File 'sig/client.rbs', line 821
def list_source_api_associations: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for a resource.
833 |
# File 'sig/client.rbs', line 833
def list_tags_for_resource: (
|
#list_types(params = {}) ⇒ Types::ListTypesResponse
Lists the types for a given API.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
844 |
# File 'sig/client.rbs', line 844
def list_types: (
|
#list_types_by_association(params = {}) ⇒ Types::ListTypesByAssociationResponse
Lists Type objects by the source API association ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
858 |
# File 'sig/client.rbs', line 858
def list_types_by_association: (
|
#put_graphql_api_environment_variables(params = {}) ⇒ Types::PutGraphqlApiEnvironmentVariablesResponse
Creates a list of environmental variables in an API by its ID value.
When creating an environmental variable, it must follow the constraints below:
-
Both JavaScript and VTL templates support environmental variables.
-
Environmental variables are not evaluated before function invocation.
-
Environmental variables only support string values.
-
Any defined value in an environmental variable is considered a string literal and not expanded.
-
Variable evaluations should ideally be performed in the function code.
When creating an environmental variable key-value pair, it must follow the additional constraints below:
-
Keys must begin with a letter.
-
Keys must be at least two characters long.
-
Keys can only contain letters, numbers, and the underscore character (_).
-
Values can be up to 512 characters long.
-
You can configure up to 50 key-value pairs in a GraphQL API.
You can create a list of environmental variables by adding it to the
environmentVariables payload as a list in the format
{"key1":"value1","key2":"value2", …}. Note that each call of the
PutGraphqlApiEnvironmentVariables action will result in the
overwriting of the existing environmental variable list of that API.
This means the existing environmental variables will be lost. To avoid
this, you must include all existing and new environmental variables in
the list each time you call this action.
872 |
# File 'sig/client.rbs', line 872
def put_graphql_api_environment_variables: (
|
#start_data_source_introspection(params = {}) ⇒ Types::StartDataSourceIntrospectionResponse
Creates a new introspection. Returns the introspectionId of the new
introspection after its creation.
885 |
# File 'sig/client.rbs', line 885
def start_data_source_introspection: (
|
#start_schema_creation(params = {}) ⇒ Types::StartSchemaCreationResponse
Adds a new schema to your GraphQL API.
This operation is asynchronous. Use to determine when it has completed.
899 |
# File 'sig/client.rbs', line 899
def start_schema_creation: (
|
#start_schema_merge(params = {}) ⇒ Types::StartSchemaMergeResponse
Initiates a merge operation. Returns a status that shows the result of the merge operation.
910 |
# File 'sig/client.rbs', line 910
def start_schema_merge: (
|
#tag_resource(params = {}) ⇒ Struct
Tags a resource with user-supplied tags.
920 |
# File 'sig/client.rbs', line 920
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Untags a resource.
930 |
# File 'sig/client.rbs', line 930
def untag_resource: (
|
#update_api(params = {}) ⇒ Types::UpdateApiResponse
Updates an Api.
941 |
# File 'sig/client.rbs', line 941
def update_api: (
|
#update_api_cache(params = {}) ⇒ Types::UpdateApiCacheResponse
Updates the cache for the GraphQL API.
954 |
# File 'sig/client.rbs', line 954
def update_api_cache: (
|
#update_api_key(params = {}) ⇒ Types::UpdateApiKeyResponse
Updates an API key. You can update the key as long as it's not deleted.
968 |
# File 'sig/client.rbs', line 968
def update_api_key: (
|
#update_channel_namespace(params = {}) ⇒ Types::UpdateChannelNamespaceResponse
Updates a ChannelNamespace associated with an Api.
981 |
# File 'sig/client.rbs', line 981
def update_channel_namespace: (
|
#update_data_source(params = {}) ⇒ Types::UpdateDataSourceResponse
Updates a DataSource object.
1004 |
# File 'sig/client.rbs', line 1004
def update_data_source: (
|
#update_domain_name(params = {}) ⇒ Types::UpdateDomainNameResponse
Updates a custom DomainName object.
1036 |
# File 'sig/client.rbs', line 1036
def update_domain_name: (
|
#update_function(params = {}) ⇒ Types::UpdateFunctionResponse
Updates a Function object.
1047 |
# File 'sig/client.rbs', line 1047
def update_function: (
|
#update_graphql_api(params = {}) ⇒ Types::UpdateGraphqlApiResponse
Updates a GraphqlApi object.
1077 |
# File 'sig/client.rbs', line 1077
def update_graphql_api: (
|
#update_resolver(params = {}) ⇒ Types::UpdateResolverResponse
Updates a Resolver object.
1125 |
# File 'sig/client.rbs', line 1125
def update_resolver: (
|
#update_source_api_association(params = {}) ⇒ Types::UpdateSourceApiAssociationResponse
Updates some of the configuration choices of a particular source API association.
1162 |
# File 'sig/client.rbs', line 1162
def update_source_api_association: (
|
#update_type(params = {}) ⇒ Types::UpdateTypeResponse
Updates a Type object.
1177 |
# File 'sig/client.rbs', line 1177
def update_type: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5122 5123 5124 |
# File 'lib/aws-sdk-appsync/client.rb', line 5122 def waiter_names [] end |