Class: Aws::AppSync::Types::ListApiKeysRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppSync::Types::ListApiKeysRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appsync/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#api_id ⇒ String
The API ID.
-
#max_results ⇒ Integer
The maximum number of results that you want the request to return.
-
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which you can use to return the next set of items in the list.
Instance Attribute Details
#api_id ⇒ String
The API ID.
3712 3713 3714 3715 3716 3717 3718 |
# File 'lib/aws-sdk-appsync/types.rb', line 3712 class ListApiKeysRequest < Struct.new( :api_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results that you want the request to return.
3712 3713 3714 3715 3716 3717 3718 |
# File 'lib/aws-sdk-appsync/types.rb', line 3712 class ListApiKeysRequest < Struct.new( :api_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which you can use to return the next set of items in the list.
3712 3713 3714 3715 3716 3717 3718 |
# File 'lib/aws-sdk-appsync/types.rb', line 3712 class ListApiKeysRequest < Struct.new( :api_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |