Class: Aws::AppSync::Types::ListApisRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppSync::Types::ListApisRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appsync/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results that you want the request to return.
-
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which you can use to return the next set of items in the list.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results that you want the request to return.
3750 3751 3752 3753 3754 3755 |
# File 'lib/aws-sdk-appsync/types.rb', line 3750 class ListApisRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which you can use to return the next set of items in the list.
3750 3751 3752 3753 3754 3755 |
# File 'lib/aws-sdk-appsync/types.rb', line 3750 class ListApisRequest < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |