Class: Aws::AppSync::Types::ListApisResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appsync/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#apisArray<Types::Api>

The Api objects.

Returns:



3769
3770
3771
3772
3773
3774
# File 'lib/aws-sdk-appsync/types.rb', line 3769

class ListApisResponse < Struct.new(
  :apis,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

An identifier that was returned from the previous call to this operation, which you can use to return the next set of items in the list.

Returns:

  • (String)


3769
3770
3771
3772
3773
3774
# File 'lib/aws-sdk-appsync/types.rb', line 3769

class ListApisResponse < Struct.new(
  :apis,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end