Class: Aws::AppSync::Types::ListChannelNamespacesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appsync/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channel_namespacesArray<Types::ChannelNamespace>

The ChannelNamespace objects.



3812
3813
3814
3815
3816
3817
# File 'lib/aws-sdk-appsync/types.rb', line 3812

class ListChannelNamespacesResponse < Struct.new(
  :channel_namespaces,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

An identifier that was returned from the previous call to this operation, which you can use to return the next set of items in the list.



3812
3813
3814
3815
3816
3817
# File 'lib/aws-sdk-appsync/types.rb', line 3812

class ListChannelNamespacesResponse < Struct.new(
  :channel_namespaces,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end