Class: Aws::AppSync::Types::ListDomainNamesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appsync/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results that you want the request to return.



3873
3874
3875
3876
3877
3878
# File 'lib/aws-sdk-appsync/types.rb', line 3873

class ListDomainNamesRequest < Struct.new(
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

An identifier that was returned from the previous call to this operation, which you can use to return the next set of items in the list.



3873
3874
3875
3876
3877
3878
# File 'lib/aws-sdk-appsync/types.rb', line 3873

class ListDomainNamesRequest < Struct.new(
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end