Class: Aws::AppSync::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::AppSync::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-appsync/client.rb
Overview
An API client for AppSync. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::AppSync::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_api(params = {}) ⇒ Types::AssociateApiResponse
Maps an endpoint to your custom domain.
-
#associate_merged_graphql_api(params = {}) ⇒ Types::AssociateMergedGraphqlApiResponse
Creates an association between a Merged API and source API using the source API’s identifier.
-
#associate_source_graphql_api(params = {}) ⇒ Types::AssociateSourceGraphqlApiResponse
Creates an association between a Merged API and source API using the Merged API’s identifier.
-
#create_api(params = {}) ⇒ Types::CreateApiResponse
Creates an ‘Api` object.
-
#create_api_cache(params = {}) ⇒ Types::CreateApiCacheResponse
Creates a cache for the GraphQL API.
-
#create_api_key(params = {}) ⇒ Types::CreateApiKeyResponse
Creates a unique key that you can distribute to clients who invoke your API.
-
#create_channel_namespace(params = {}) ⇒ Types::CreateChannelNamespaceResponse
Creates a ‘ChannelNamespace` for an `Api`.
-
#create_data_source(params = {}) ⇒ Types::CreateDataSourceResponse
Creates a ‘DataSource` object.
-
#create_domain_name(params = {}) ⇒ Types::CreateDomainNameResponse
Creates a custom ‘DomainName` object.
-
#create_function(params = {}) ⇒ Types::CreateFunctionResponse
Creates a ‘Function` object.
-
#create_graphql_api(params = {}) ⇒ Types::CreateGraphqlApiResponse
Creates a ‘GraphqlApi` object.
-
#create_resolver(params = {}) ⇒ Types::CreateResolverResponse
Creates a ‘Resolver` object.
-
#create_type(params = {}) ⇒ Types::CreateTypeResponse
Creates a ‘Type` object.
-
#delete_api(params = {}) ⇒ Struct
Deletes an ‘Api` object.
-
#delete_api_cache(params = {}) ⇒ Struct
Deletes an ‘ApiCache` object.
-
#delete_api_key(params = {}) ⇒ Struct
Deletes an API key.
-
#delete_channel_namespace(params = {}) ⇒ Struct
Deletes a ‘ChannelNamespace`.
-
#delete_data_source(params = {}) ⇒ Struct
Deletes a ‘DataSource` object.
-
#delete_domain_name(params = {}) ⇒ Struct
Deletes a custom ‘DomainName` object.
-
#delete_function(params = {}) ⇒ Struct
Deletes a ‘Function`.
-
#delete_graphql_api(params = {}) ⇒ Struct
Deletes a ‘GraphqlApi` object.
-
#delete_resolver(params = {}) ⇒ Struct
Deletes a ‘Resolver` object.
-
#delete_type(params = {}) ⇒ Struct
Deletes a ‘Type` object.
-
#disassociate_api(params = {}) ⇒ Struct
Removes an ‘ApiAssociation` object from a custom domain.
-
#disassociate_merged_graphql_api(params = {}) ⇒ Types::DisassociateMergedGraphqlApiResponse
Deletes an association between a Merged API and source API using the source API’s identifier and the association ID.
-
#disassociate_source_graphql_api(params = {}) ⇒ Types::DisassociateSourceGraphqlApiResponse
Deletes an association between a Merged API and source API using the Merged API’s identifier and the association ID.
-
#evaluate_code(params = {}) ⇒ Types::EvaluateCodeResponse
Evaluates the given code and returns the response.
-
#evaluate_mapping_template(params = {}) ⇒ Types::EvaluateMappingTemplateResponse
Evaluates a given template and returns the response.
-
#flush_api_cache(params = {}) ⇒ Struct
Flushes an ‘ApiCache` object.
-
#get_api(params = {}) ⇒ Types::GetApiResponse
Retrieves an ‘Api` object.
-
#get_api_association(params = {}) ⇒ Types::GetApiAssociationResponse
Retrieves an ‘ApiAssociation` object.
-
#get_api_cache(params = {}) ⇒ Types::GetApiCacheResponse
Retrieves an ‘ApiCache` object.
-
#get_channel_namespace(params = {}) ⇒ Types::GetChannelNamespaceResponse
Retrieves the channel namespace for a specified ‘Api`.
-
#get_data_source(params = {}) ⇒ Types::GetDataSourceResponse
Retrieves a ‘DataSource` object.
-
#get_data_source_introspection(params = {}) ⇒ Types::GetDataSourceIntrospectionResponse
Retrieves the record of an existing introspection.
-
#get_domain_name(params = {}) ⇒ Types::GetDomainNameResponse
Retrieves a custom ‘DomainName` object.
-
#get_function(params = {}) ⇒ Types::GetFunctionResponse
Get a ‘Function`.
-
#get_graphql_api(params = {}) ⇒ Types::GetGraphqlApiResponse
Retrieves a ‘GraphqlApi` object.
-
#get_graphql_api_environment_variables(params = {}) ⇒ Types::GetGraphqlApiEnvironmentVariablesResponse
Retrieves the list of environmental variable key-value pairs associated with an API by its ID value.
-
#get_introspection_schema(params = {}) ⇒ Types::GetIntrospectionSchemaResponse
Retrieves the introspection schema for a GraphQL API.
-
#get_resolver(params = {}) ⇒ Types::GetResolverResponse
Retrieves a ‘Resolver` object.
-
#get_schema_creation_status(params = {}) ⇒ Types::GetSchemaCreationStatusResponse
Retrieves the current status of a schema creation operation.
-
#get_source_api_association(params = {}) ⇒ Types::GetSourceApiAssociationResponse
Retrieves a ‘SourceApiAssociation` object.
-
#get_type(params = {}) ⇒ Types::GetTypeResponse
Retrieves a ‘Type` object.
-
#list_api_keys(params = {}) ⇒ Types::ListApiKeysResponse
Lists the API keys for a given API.
-
#list_apis(params = {}) ⇒ Types::ListApisResponse
Lists the APIs in your AppSync account.
-
#list_channel_namespaces(params = {}) ⇒ Types::ListChannelNamespacesResponse
Lists the channel namespaces for a specified ‘Api`.
-
#list_data_sources(params = {}) ⇒ Types::ListDataSourcesResponse
Lists the data sources for a given API.
-
#list_domain_names(params = {}) ⇒ Types::ListDomainNamesResponse
Lists multiple custom domain names.
-
#list_functions(params = {}) ⇒ Types::ListFunctionsResponse
List multiple functions.
-
#list_graphql_apis(params = {}) ⇒ Types::ListGraphqlApisResponse
Lists your GraphQL APIs.
-
#list_resolvers(params = {}) ⇒ Types::ListResolversResponse
Lists the resolvers for a given API and type.
-
#list_resolvers_by_function(params = {}) ⇒ Types::ListResolversByFunctionResponse
List the resolvers that are associated with a specific function.
-
#list_source_api_associations(params = {}) ⇒ Types::ListSourceApiAssociationsResponse
Lists the ‘SourceApiAssociationSummary` data.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for a resource.
-
#list_types(params = {}) ⇒ Types::ListTypesResponse
Lists the types for a given API.
-
#list_types_by_association(params = {}) ⇒ Types::ListTypesByAssociationResponse
Lists ‘Type` objects by the source API association ID.
-
#put_graphql_api_environment_variables(params = {}) ⇒ Types::PutGraphqlApiEnvironmentVariablesResponse
Creates a list of environmental variables in an API by its ID value.
-
#start_data_source_introspection(params = {}) ⇒ Types::StartDataSourceIntrospectionResponse
Creates a new introspection.
-
#start_schema_creation(params = {}) ⇒ Types::StartSchemaCreationResponse
Adds a new schema to your GraphQL API.
-
#start_schema_merge(params = {}) ⇒ Types::StartSchemaMergeResponse
Initiates a merge operation.
-
#tag_resource(params = {}) ⇒ Struct
Tags a resource with user-supplied tags.
-
#untag_resource(params = {}) ⇒ Struct
Untags a resource.
-
#update_api(params = {}) ⇒ Types::UpdateApiResponse
Updates an ‘Api`.
-
#update_api_cache(params = {}) ⇒ Types::UpdateApiCacheResponse
Updates the cache for the GraphQL API.
-
#update_api_key(params = {}) ⇒ Types::UpdateApiKeyResponse
Updates an API key.
-
#update_channel_namespace(params = {}) ⇒ Types::UpdateChannelNamespaceResponse
Updates a ‘ChannelNamespace` associated with an `Api`.
-
#update_data_source(params = {}) ⇒ Types::UpdateDataSourceResponse
Updates a ‘DataSource` object.
-
#update_domain_name(params = {}) ⇒ Types::UpdateDomainNameResponse
Updates a custom ‘DomainName` object.
-
#update_function(params = {}) ⇒ Types::UpdateFunctionResponse
Updates a ‘Function` object.
-
#update_graphql_api(params = {}) ⇒ Types::UpdateGraphqlApiResponse
Updates a ‘GraphqlApi` object.
-
#update_resolver(params = {}) ⇒ Types::UpdateResolverResponse
Updates a ‘Resolver` object.
-
#update_source_api_association(params = {}) ⇒ Types::UpdateSourceApiAssociationResponse
Updates some of the configuration choices of a particular source API association.
-
#update_type(params = {}) ⇒ Types::UpdateTypeResponse
Updates a ‘Type` object.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-appsync/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5129 5130 5131 |
# File 'lib/aws-sdk-appsync/client.rb', line 5129 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5132 5133 5134 |
# File 'lib/aws-sdk-appsync/client.rb', line 5132 def errors_module Errors end |
Instance Method Details
#associate_api(params = {}) ⇒ Types::AssociateApiResponse
Maps an endpoint to your custom domain.
507 508 509 510 |
# File 'lib/aws-sdk-appsync/client.rb', line 507 def associate_api(params = {}, = {}) req = build_request(:associate_api, params) req.send_request() end |
#associate_merged_graphql_api(params = {}) ⇒ Types::AssociateMergedGraphqlApiResponse
Creates an association between a Merged API and source API using the source API’s identifier.
568 569 570 571 |
# File 'lib/aws-sdk-appsync/client.rb', line 568 def associate_merged_graphql_api(params = {}, = {}) req = build_request(:associate_merged_graphql_api, params) req.send_request() end |
#associate_source_graphql_api(params = {}) ⇒ Types::AssociateSourceGraphqlApiResponse
Creates an association between a Merged API and source API using the Merged API’s identifier.
629 630 631 632 |
# File 'lib/aws-sdk-appsync/client.rb', line 629 def associate_source_graphql_api(params = {}, = {}) req = build_request(:associate_source_graphql_api, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5102 5103 5104 5105 5106 5107 5108 5109 5110 5111 5112 5113 5114 5115 5116 5117 5118 |
# File 'lib/aws-sdk-appsync/client.rb', line 5102 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::AppSync') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-appsync' context[:gem_version] = '1.123.0' Seahorse::Client::Request.new(handlers, context) end |
#create_api(params = {}) ⇒ Types::CreateApiResponse
Creates an ‘Api` object. Use this operation to create an AppSync API with your preferred configuration, such as an Event API that provides real-time message publishing and message subscriptions over WebSockets.
747 748 749 750 |
# File 'lib/aws-sdk-appsync/client.rb', line 747 def create_api(params = {}, = {}) req = build_request(:create_api, params) req.send_request() end |
#create_api_cache(params = {}) ⇒ Types::CreateApiCacheResponse
Creates a cache for the GraphQL API.
868 869 870 871 |
# File 'lib/aws-sdk-appsync/client.rb', line 868 def create_api_cache(params = {}, = {}) req = build_request(:create_api_cache, params) req.send_request() end |
#create_api_key(params = {}) ⇒ Types::CreateApiKeyResponse
Creates a unique key that you can distribute to clients who invoke your API.
911 912 913 914 |
# File 'lib/aws-sdk-appsync/client.rb', line 911 def create_api_key(params = {}, = {}) req = build_request(:create_api_key, params) req.send_request() end |
#create_channel_namespace(params = {}) ⇒ Types::CreateChannelNamespaceResponse
Creates a ‘ChannelNamespace` for an `Api`.
1015 1016 1017 1018 |
# File 'lib/aws-sdk-appsync/client.rb', line 1015 def create_channel_namespace(params = {}, = {}) req = build_request(:create_channel_namespace, params) req.send_request() end |
#create_data_source(params = {}) ⇒ Types::CreateDataSourceResponse
Creates a ‘DataSource` object.
1171 1172 1173 1174 |
# File 'lib/aws-sdk-appsync/client.rb', line 1171 def create_data_source(params = {}, = {}) req = build_request(:create_data_source, params) req.send_request() end |
#create_domain_name(params = {}) ⇒ Types::CreateDomainNameResponse
Creates a custom ‘DomainName` object.
1222 1223 1224 1225 |
# File 'lib/aws-sdk-appsync/client.rb', line 1222 def create_domain_name(params = {}, = {}) req = build_request(:create_domain_name, params) req.send_request() end |
#create_function(params = {}) ⇒ Types::CreateFunctionResponse
Creates a ‘Function` object.
A function is a reusable entity. You can use multiple functions to compose the resolver logic.
1327 1328 1329 1330 |
# File 'lib/aws-sdk-appsync/client.rb', line 1327 def create_function(params = {}, = {}) req = build_request(:create_function, params) req.send_request() end |
#create_graphql_api(params = {}) ⇒ Types::CreateGraphqlApiResponse
Creates a ‘GraphqlApi` object.
1548 1549 1550 1551 |
# File 'lib/aws-sdk-appsync/client.rb', line 1548 def create_graphql_api(params = {}, = {}) req = build_request(:create_graphql_api, params) req.send_request() end |
#create_resolver(params = {}) ⇒ Types::CreateResolverResponse
Creates a ‘Resolver` object.
A resolver converts incoming requests into a format that a data source can understand, and converts the data source’s responses into GraphQL.
1694 1695 1696 1697 |
# File 'lib/aws-sdk-appsync/client.rb', line 1694 def create_resolver(params = {}, = {}) req = build_request(:create_resolver, params) req.send_request() end |
#create_type(params = {}) ⇒ Types::CreateTypeResponse
Creates a ‘Type` object.
1741 1742 1743 1744 |
# File 'lib/aws-sdk-appsync/client.rb', line 1741 def create_type(params = {}, = {}) req = build_request(:create_type, params) req.send_request() end |
#delete_api(params = {}) ⇒ Struct
Deletes an ‘Api` object
1763 1764 1765 1766 |
# File 'lib/aws-sdk-appsync/client.rb', line 1763 def delete_api(params = {}, = {}) req = build_request(:delete_api, params) req.send_request() end |
#delete_api_cache(params = {}) ⇒ Struct
Deletes an ‘ApiCache` object.
1785 1786 1787 1788 |
# File 'lib/aws-sdk-appsync/client.rb', line 1785 def delete_api_cache(params = {}, = {}) req = build_request(:delete_api_cache, params) req.send_request() end |
#delete_api_key(params = {}) ⇒ Struct
Deletes an API key.
1811 1812 1813 1814 |
# File 'lib/aws-sdk-appsync/client.rb', line 1811 def delete_api_key(params = {}, = {}) req = build_request(:delete_api_key, params) req.send_request() end |
#delete_channel_namespace(params = {}) ⇒ Struct
Deletes a ‘ChannelNamespace`.
1837 1838 1839 1840 |
# File 'lib/aws-sdk-appsync/client.rb', line 1837 def delete_channel_namespace(params = {}, = {}) req = build_request(:delete_channel_namespace, params) req.send_request() end |
#delete_data_source(params = {}) ⇒ Struct
Deletes a ‘DataSource` object.
1863 1864 1865 1866 |
# File 'lib/aws-sdk-appsync/client.rb', line 1863 def delete_data_source(params = {}, = {}) req = build_request(:delete_data_source, params) req.send_request() end |
#delete_domain_name(params = {}) ⇒ Struct
Deletes a custom ‘DomainName` object.
1885 1886 1887 1888 |
# File 'lib/aws-sdk-appsync/client.rb', line 1885 def delete_domain_name(params = {}, = {}) req = build_request(:delete_domain_name, params) req.send_request() end |
#delete_function(params = {}) ⇒ Struct
Deletes a ‘Function`.
1911 1912 1913 1914 |
# File 'lib/aws-sdk-appsync/client.rb', line 1911 def delete_function(params = {}, = {}) req = build_request(:delete_function, params) req.send_request() end |
#delete_graphql_api(params = {}) ⇒ Struct
Deletes a ‘GraphqlApi` object.
1933 1934 1935 1936 |
# File 'lib/aws-sdk-appsync/client.rb', line 1933 def delete_graphql_api(params = {}, = {}) req = build_request(:delete_graphql_api, params) req.send_request() end |
#delete_resolver(params = {}) ⇒ Struct
Deletes a ‘Resolver` object.
1963 1964 1965 1966 |
# File 'lib/aws-sdk-appsync/client.rb', line 1963 def delete_resolver(params = {}, = {}) req = build_request(:delete_resolver, params) req.send_request() end |
#delete_type(params = {}) ⇒ Struct
Deletes a ‘Type` object.
1989 1990 1991 1992 |
# File 'lib/aws-sdk-appsync/client.rb', line 1989 def delete_type(params = {}, = {}) req = build_request(:delete_type, params) req.send_request() end |
#disassociate_api(params = {}) ⇒ Struct
Removes an ‘ApiAssociation` object from a custom domain.
2011 2012 2013 2014 |
# File 'lib/aws-sdk-appsync/client.rb', line 2011 def disassociate_api(params = {}, = {}) req = build_request(:disassociate_api, params) req.send_request() end |
#disassociate_merged_graphql_api(params = {}) ⇒ Types::DisassociateMergedGraphqlApiResponse
Deletes an association between a Merged API and source API using the source API’s identifier and the association ID.
2049 2050 2051 2052 |
# File 'lib/aws-sdk-appsync/client.rb', line 2049 def disassociate_merged_graphql_api(params = {}, = {}) req = build_request(:disassociate_merged_graphql_api, params) req.send_request() end |
#disassociate_source_graphql_api(params = {}) ⇒ Types::DisassociateSourceGraphqlApiResponse
Deletes an association between a Merged API and source API using the Merged API’s identifier and the association ID.
2087 2088 2089 2090 |
# File 'lib/aws-sdk-appsync/client.rb', line 2087 def disassociate_source_graphql_api(params = {}, = {}) req = build_request(:disassociate_source_graphql_api, params) req.send_request() end |
#evaluate_code(params = {}) ⇒ Types::EvaluateCodeResponse
Evaluates the given code and returns the response. The code definition requirements depend on the specified runtime. For ‘APPSYNC_JS` runtimes, the code defines the request and response functions. The request function takes the incoming request after a GraphQL operation is parsed and converts it into a request configuration for the selected data source operation. The response function interprets responses from the data source and maps it to the shape of the GraphQL field output type.
2157 2158 2159 2160 |
# File 'lib/aws-sdk-appsync/client.rb', line 2157 def evaluate_code(params = {}, = {}) req = build_request(:evaluate_code, params) req.send_request() end |
#evaluate_mapping_template(params = {}) ⇒ Types::EvaluateMappingTemplateResponse
Evaluates a given template and returns the response. The mapping template can be a request or response template.
Request templates take the incoming request after a GraphQL operation is parsed and convert it into a request configuration for the selected data source operation. Response templates interpret responses from the data source and map it to the shape of the GraphQL field output type.
Mapping templates are written in the Apache Velocity Template Language (VTL).
2209 2210 2211 2212 |
# File 'lib/aws-sdk-appsync/client.rb', line 2209 def evaluate_mapping_template(params = {}, = {}) req = build_request(:evaluate_mapping_template, params) req.send_request() end |
#flush_api_cache(params = {}) ⇒ Struct
Flushes an ‘ApiCache` object.
2231 2232 2233 2234 |
# File 'lib/aws-sdk-appsync/client.rb', line 2231 def flush_api_cache(params = {}, = {}) req = build_request(:flush_api_cache, params) req.send_request() end |
#get_api(params = {}) ⇒ Types::GetApiResponse
Retrieves an ‘Api` object.
2289 2290 2291 2292 |
# File 'lib/aws-sdk-appsync/client.rb', line 2289 def get_api(params = {}, = {}) req = build_request(:get_api, params) req.send_request() end |
#get_api_association(params = {}) ⇒ Types::GetApiAssociationResponse
Retrieves an ‘ApiAssociation` object.
2320 2321 2322 2323 |
# File 'lib/aws-sdk-appsync/client.rb', line 2320 def get_api_association(params = {}, = {}) req = build_request(:get_api_association, params) req.send_request() end |
#get_api_cache(params = {}) ⇒ Types::GetApiCacheResponse
Retrieves an ‘ApiCache` object.
2354 2355 2356 2357 |
# File 'lib/aws-sdk-appsync/client.rb', line 2354 def get_api_cache(params = {}, = {}) req = build_request(:get_api_cache, params) req.send_request() end |
#get_channel_namespace(params = {}) ⇒ Types::GetChannelNamespaceResponse
Retrieves the channel namespace for a specified ‘Api`.
2403 2404 2405 2406 |
# File 'lib/aws-sdk-appsync/client.rb', line 2403 def get_channel_namespace(params = {}, = {}) req = build_request(:get_channel_namespace, params) req.send_request() end |
#get_data_source(params = {}) ⇒ Types::GetDataSourceResponse
Retrieves a ‘DataSource` object.
2463 2464 2465 2466 |
# File 'lib/aws-sdk-appsync/client.rb', line 2463 def get_data_source(params = {}, = {}) req = build_request(:get_data_source, params) req.send_request() end |
#get_data_source_introspection(params = {}) ⇒ Types::GetDataSourceIntrospectionResponse
Retrieves the record of an existing introspection. If the retrieval is successful, the result of the instrospection will also be returned. If the retrieval fails the operation, an error message will be returned instead.
2537 2538 2539 2540 |
# File 'lib/aws-sdk-appsync/client.rb', line 2537 def get_data_source_introspection(params = {}, = {}) req = build_request(:get_data_source_introspection, params) req.send_request() end |
#get_domain_name(params = {}) ⇒ Types::GetDomainNameResponse
Retrieves a custom ‘DomainName` object.
2572 2573 2574 2575 |
# File 'lib/aws-sdk-appsync/client.rb', line 2572 def get_domain_name(params = {}, = {}) req = build_request(:get_domain_name, params) req.send_request() end |
#get_function(params = {}) ⇒ Types::GetFunctionResponse
Get a ‘Function`.
2618 2619 2620 2621 |
# File 'lib/aws-sdk-appsync/client.rb', line 2618 def get_function(params = {}, = {}) req = build_request(:get_function, params) req.send_request() end |
#get_graphql_api(params = {}) ⇒ Types::GetGraphqlApiResponse
Retrieves a ‘GraphqlApi` object.
2694 2695 2696 2697 |
# File 'lib/aws-sdk-appsync/client.rb', line 2694 def get_graphql_api(params = {}, = {}) req = build_request(:get_graphql_api, params) req.send_request() end |
#get_graphql_api_environment_variables(params = {}) ⇒ Types::GetGraphqlApiEnvironmentVariablesResponse
Retrieves the list of environmental variable key-value pairs associated with an API by its ID value.
2725 2726 2727 2728 |
# File 'lib/aws-sdk-appsync/client.rb', line 2725 def get_graphql_api_environment_variables(params = {}, = {}) req = build_request(:get_graphql_api_environment_variables, params) req.send_request() end |
#get_introspection_schema(params = {}) ⇒ Types::GetIntrospectionSchemaResponse
Retrieves the introspection schema for a GraphQL API.
2762 2763 2764 2765 |
# File 'lib/aws-sdk-appsync/client.rb', line 2762 def get_introspection_schema(params = {}, = {}) req = build_request(:get_introspection_schema, params) req.send_request() end |
#get_resolver(params = {}) ⇒ Types::GetResolverResponse
Retrieves a ‘Resolver` object.
2817 2818 2819 2820 |
# File 'lib/aws-sdk-appsync/client.rb', line 2817 def get_resolver(params = {}, = {}) req = build_request(:get_resolver, params) req.send_request() end |
#get_schema_creation_status(params = {}) ⇒ Types::GetSchemaCreationStatusResponse
Retrieves the current status of a schema creation operation.
2847 2848 2849 2850 |
# File 'lib/aws-sdk-appsync/client.rb', line 2847 def get_schema_creation_status(params = {}, = {}) req = build_request(:get_schema_creation_status, params) req.send_request() end |
#get_source_api_association(params = {}) ⇒ Types::GetSourceApiAssociationResponse
Retrieves a ‘SourceApiAssociation` object.
2894 2895 2896 2897 |
# File 'lib/aws-sdk-appsync/client.rb', line 2894 def get_source_api_association(params = {}, = {}) req = build_request(:get_source_api_association, params) req.send_request() end |
#get_type(params = {}) ⇒ Types::GetTypeResponse
Retrieves a ‘Type` object.
2934 2935 2936 2937 |
# File 'lib/aws-sdk-appsync/client.rb', line 2934 def get_type(params = {}, = {}) req = build_request(:get_type, params) req.send_request() end |
#list_api_keys(params = {}) ⇒ Types::ListApiKeysResponse
Lists the API keys for a given API.
<note markdown=“1”> API keys are deleted automatically 60 days after they expire. However, they may still be included in the response until they have actually been deleted. You can safely call ‘DeleteApiKey` to manually delete a key before it’s automatically deleted.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2987 2988 2989 2990 |
# File 'lib/aws-sdk-appsync/client.rb', line 2987 def list_api_keys(params = {}, = {}) req = build_request(:list_api_keys, params) req.send_request() end |
#list_apis(params = {}) ⇒ Types::ListApisResponse
Lists the APIs in your AppSync account.
‘ListApis` returns only the high level API details. For more detailed information about an API, use `GetApi`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3059 3060 3061 3062 |
# File 'lib/aws-sdk-appsync/client.rb', line 3059 def list_apis(params = {}, = {}) req = build_request(:list_apis, params) req.send_request() end |
#list_channel_namespaces(params = {}) ⇒ Types::ListChannelNamespacesResponse
Lists the channel namespaces for a specified ‘Api`.
‘ListChannelNamespaces` returns only high level details for the channel namespace. To retrieve code handlers, use `GetChannelNamespace`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3123 3124 3125 3126 |
# File 'lib/aws-sdk-appsync/client.rb', line 3123 def list_channel_namespaces(params = {}, = {}) req = build_request(:list_channel_namespaces, params) req.send_request() end |
#list_data_sources(params = {}) ⇒ Types::ListDataSourcesResponse
Lists the data sources for a given API.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3194 3195 3196 3197 |
# File 'lib/aws-sdk-appsync/client.rb', line 3194 def list_data_sources(params = {}, = {}) req = build_request(:list_data_sources, params) req.send_request() end |
#list_domain_names(params = {}) ⇒ Types::ListDomainNamesResponse
Lists multiple custom domain names.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3240 3241 3242 3243 |
# File 'lib/aws-sdk-appsync/client.rb', line 3240 def list_domain_names(params = {}, = {}) req = build_request(:list_domain_names, params) req.send_request() end |
#list_functions(params = {}) ⇒ Types::ListFunctionsResponse
List multiple functions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3297 3298 3299 3300 |
# File 'lib/aws-sdk-appsync/client.rb', line 3297 def list_functions(params = {}, = {}) req = build_request(:list_functions, params) req.send_request() end |
#list_graphql_apis(params = {}) ⇒ Types::ListGraphqlApisResponse
Lists your GraphQL APIs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3393 3394 3395 3396 |
# File 'lib/aws-sdk-appsync/client.rb', line 3393 def list_graphql_apis(params = {}, = {}) req = build_request(:list_graphql_apis, params) req.send_request() end |
#list_resolvers(params = {}) ⇒ Types::ListResolversResponse
Lists the resolvers for a given API and type.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3459 3460 3461 3462 |
# File 'lib/aws-sdk-appsync/client.rb', line 3459 def list_resolvers(params = {}, = {}) req = build_request(:list_resolvers, params) req.send_request() end |
#list_resolvers_by_function(params = {}) ⇒ Types::ListResolversByFunctionResponse
List the resolvers that are associated with a specific function.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3525 3526 3527 3528 |
# File 'lib/aws-sdk-appsync/client.rb', line 3525 def list_resolvers_by_function(params = {}, = {}) req = build_request(:list_resolvers_by_function, params) req.send_request() end |
#list_source_api_associations(params = {}) ⇒ Types::ListSourceApiAssociationsResponse
Lists the ‘SourceApiAssociationSummary` data.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3574 3575 3576 3577 |
# File 'lib/aws-sdk-appsync/client.rb', line 3574 def list_source_api_associations(params = {}, = {}) req = build_request(:list_source_api_associations, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for a resource.
3603 3604 3605 3606 |
# File 'lib/aws-sdk-appsync/client.rb', line 3603 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_types(params = {}) ⇒ Types::ListTypesResponse
Lists the types for a given API.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3654 3655 3656 3657 |
# File 'lib/aws-sdk-appsync/client.rb', line 3654 def list_types(params = {}, = {}) req = build_request(:list_types, params) req.send_request() end |
#list_types_by_association(params = {}) ⇒ Types::ListTypesByAssociationResponse
Lists ‘Type` objects by the source API association ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3714 3715 3716 3717 |
# File 'lib/aws-sdk-appsync/client.rb', line 3714 def list_types_by_association(params = {}, = {}) req = build_request(:list_types_by_association, params) req.send_request() end |
#put_graphql_api_environment_variables(params = {}) ⇒ Types::PutGraphqlApiEnvironmentVariablesResponse
Creates a list of environmental variables in an API by its ID value.
When creating an environmental variable, it must follow the constraints below:
-
Both JavaScript and VTL templates support environmental variables.
-
Environmental variables are not evaluated before function invocation.
-
Environmental variables only support string values.
-
Any defined value in an environmental variable is considered a string literal and not expanded.
-
Variable evaluations should ideally be performed in the function code.
When creating an environmental variable key-value pair, it must follow the additional constraints below:
-
Keys must begin with a letter.
-
Keys must be at least two characters long.
-
Keys can only contain letters, numbers, and the underscore character (_).
-
Values can be up to 512 characters long.
-
You can configure up to 50 key-value pairs in a GraphQL API.
You can create a list of environmental variables by adding it to the ‘environmentVariables` payload as a list in the format `…`. Note that each call of the `PutGraphqlApiEnvironmentVariables` action will result in the overwriting of the existing environmental variable list of that API. This means the existing environmental variables will be lost. To avoid this, you must include all existing and new environmental variables in the list each time you call this action.
3812 3813 3814 3815 |
# File 'lib/aws-sdk-appsync/client.rb', line 3812 def put_graphql_api_environment_variables(params = {}, = {}) req = build_request(:put_graphql_api_environment_variables, params) req.send_request() end |
#start_data_source_introspection(params = {}) ⇒ Types::StartDataSourceIntrospectionResponse
Creates a new introspection. Returns the ‘introspectionId` of the new introspection after its creation.
3849 3850 3851 3852 |
# File 'lib/aws-sdk-appsync/client.rb', line 3849 def start_data_source_introspection(params = {}, = {}) req = build_request(:start_data_source_introspection, params) req.send_request() end |
#start_schema_creation(params = {}) ⇒ Types::StartSchemaCreationResponse
Adds a new schema to your GraphQL API.
This operation is asynchronous. Use to determine when it has completed.
3884 3885 3886 3887 |
# File 'lib/aws-sdk-appsync/client.rb', line 3884 def start_schema_creation(params = {}, = {}) req = build_request(:start_schema_creation, params) req.send_request() end |
#start_schema_merge(params = {}) ⇒ Types::StartSchemaMergeResponse
Initiates a merge operation. Returns a status that shows the result of the merge operation.
3922 3923 3924 3925 |
# File 'lib/aws-sdk-appsync/client.rb', line 3922 def start_schema_merge(params = {}, = {}) req = build_request(:start_schema_merge, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Tags a resource with user-supplied tags.
3950 3951 3952 3953 |
# File 'lib/aws-sdk-appsync/client.rb', line 3950 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Untags a resource.
3976 3977 3978 3979 |
# File 'lib/aws-sdk-appsync/client.rb', line 3976 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_api(params = {}) ⇒ Types::UpdateApiResponse
Updates an ‘Api`.
4089 4090 4091 4092 |
# File 'lib/aws-sdk-appsync/client.rb', line 4089 def update_api(params = {}, = {}) req = build_request(:update_api, params) req.send_request() end |
#update_api_cache(params = {}) ⇒ Types::UpdateApiCacheResponse
Updates the cache for the GraphQL API.
4200 4201 4202 4203 |
# File 'lib/aws-sdk-appsync/client.rb', line 4200 def update_api_cache(params = {}, = {}) req = build_request(:update_api_cache, params) req.send_request() end |
#update_api_key(params = {}) ⇒ Types::UpdateApiKeyResponse
Updates an API key. You can update the key as long as it’s not deleted.
4246 4247 4248 4249 |
# File 'lib/aws-sdk-appsync/client.rb', line 4246 def update_api_key(params = {}, = {}) req = build_request(:update_api_key, params) req.send_request() end |
#update_channel_namespace(params = {}) ⇒ Types::UpdateChannelNamespaceResponse
Updates a ‘ChannelNamespace` associated with an `Api`.
4343 4344 4345 4346 |
# File 'lib/aws-sdk-appsync/client.rb', line 4343 def update_channel_namespace(params = {}, = {}) req = build_request(:update_channel_namespace, params) req.send_request() end |
#update_data_source(params = {}) ⇒ Types::UpdateDataSourceResponse
Updates a ‘DataSource` object.
4497 4498 4499 4500 |
# File 'lib/aws-sdk-appsync/client.rb', line 4497 def update_data_source(params = {}, = {}) req = build_request(:update_data_source, params) req.send_request() end |
#update_domain_name(params = {}) ⇒ Types::UpdateDomainNameResponse
Updates a custom ‘DomainName` object.
4536 4537 4538 4539 |
# File 'lib/aws-sdk-appsync/client.rb', line 4536 def update_domain_name(params = {}, = {}) req = build_request(:update_domain_name, params) req.send_request() end |
#update_function(params = {}) ⇒ Types::UpdateFunctionResponse
Updates a ‘Function` object.
4642 4643 4644 4645 |
# File 'lib/aws-sdk-appsync/client.rb', line 4642 def update_function(params = {}, = {}) req = build_request(:update_function, params) req.send_request() end |
#update_graphql_api(params = {}) ⇒ Types::UpdateGraphqlApiResponse
Updates a ‘GraphqlApi` object.
4849 4850 4851 4852 |
# File 'lib/aws-sdk-appsync/client.rb', line 4849 def update_graphql_api(params = {}, = {}) req = build_request(:update_graphql_api, params) req.send_request() end |
#update_resolver(params = {}) ⇒ Types::UpdateResolverResponse
Updates a ‘Resolver` object.
4991 4992 4993 4994 |
# File 'lib/aws-sdk-appsync/client.rb', line 4991 def update_resolver(params = {}, = {}) req = build_request(:update_resolver, params) req.send_request() end |
#update_source_api_association(params = {}) ⇒ Types::UpdateSourceApiAssociationResponse
Updates some of the configuration choices of a particular source API association.
5049 5050 5051 5052 |
# File 'lib/aws-sdk-appsync/client.rb', line 5049 def update_source_api_association(params = {}, = {}) req = build_request(:update_source_api_association, params) req.send_request() end |
#update_type(params = {}) ⇒ Types::UpdateTypeResponse
Updates a ‘Type` object.
5093 5094 5095 5096 |
# File 'lib/aws-sdk-appsync/client.rb', line 5093 def update_type(params = {}, = {}) req = build_request(:update_type, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
5122 5123 5124 |
# File 'lib/aws-sdk-appsync/client.rb', line 5122 def waiter_names [] end |