Class: Aws::AppSync::Types::ListApisResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::AppSync::Types::ListApisResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appsync/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#apis ⇒ Array<Types::Api>
The
Apiobjects. -
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which you can use to return the next set of items in the list.
Instance Attribute Details
#apis ⇒ Array<Types::Api>
The Api objects.
3769 3770 3771 3772 3773 3774 |
# File 'lib/aws-sdk-appsync/types.rb', line 3769 class ListApisResponse < Struct.new( :apis, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which you can use to return the next set of items in the list.
3769 3770 3771 3772 3773 3774 |
# File 'lib/aws-sdk-appsync/types.rb', line 3769 class ListApisResponse < Struct.new( :apis, :next_token) SENSITIVE = [] include Aws::Structure end |